[![linux](https://github.com/IMMM-SFA/msd_uncertainty_ebook/actions/workflows/linux.yml/badge.svg)](https://github.com/IMMM-SFA/msd_uncertainty_ebook/actions/workflows/linux.yml) [![osx](https://github.com/IMMM-SFA/msd_uncertainty_ebook/actions/workflows/osx.yml/badge.svg)](https://github.com/IMMM-SFA/msd_uncertainty_ebook/actions/workflows/osx.yml) [![windows](https://github.com/IMMM-SFA/msd_uncertainty_ebook/actions/workflows/windows.yml/badge.svg)](https://github.com/IMMM-SFA/msd_uncertainty_ebook/actions/workflows/windows.yml) [![codecov](https://codecov.io/gh/IMMM-SFA/msd_uncertainty_ebook/branch/dev/graph/badge.svg?token=sc7PduW907)](https://codecov.io/gh/IMMM-SFA/msd_uncertainty_ebook) 

## Addressing Uncertainty in MultiSector Dynamics Research

### Install the supporting Python package

```bash
pip install msdbook
```
